;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "evil-matchit" "20251212.1256"
  "Vim matchit ported to Evil."
  '((emacs "27.1"))
  :url "http://github.com/redguardtoo/evil-matchit"
  :commit "eb2b0c776c9d1cf3199c24473499ce4adfa44178"
  :revdesc "eb2b0c776c9d"
  :keywords '("matchit" "vim" "evil")
  :authors '(("Chen Bin" . "chenbin.sh@gmail.com"))
  :maintainers '(("Chen Bin" . "chenbin.sh@gmail.com")))
